/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IClient, IConnected } from "@fluidframework/protocol-definitions";
import { IDatabaseManager, IDocumentStorage, IServiceConfiguration, IWebSocket, IWebSocketServer } from "@fluidframework/server-services-core";
import { ITestDbFactory } from "@fluidframework/server-test-utils";
import { LocalWebSocketServer } from "./localWebSocketServer";
/**
 * Items needed for handling deltas.
 */
export interface ILocalDeltaConnectionServer {
    webSocketServer: IWebSocketServer;
    databaseManager: IDatabaseManager;
    testDbFactory: ITestDbFactory;
    close(): Promise<void>;
    hasPendingWork(): Promise<boolean>;
    connectWebSocket(tenantId: string, documentId: string, token: string, client: IClient, protocolVersions: string[]): [IWebSocket, Promise<IConnected>];
}
/**
 * Implementation of local delta connection server.
 */
export declare class LocalDeltaConnectionServer implements ILocalDeltaConnectionServer {
    webSocketServer: LocalWebSocketServer;
    databaseManager: IDatabaseManager;
    private readonly ordererManager;
    testDbFactory: ITestDbFactory;
    documentStorage: IDocumentStorage;
    private readonly logger;
    /**
     * Creates and returns a local delta connection server.
     */
    static create(testDbFactory?: ITestDbFactory, serviceConfiguration?: Partial<IServiceConfiguration>): ILocalDeltaConnectionServer;
    private constructor();
    close(): Promise<void>;
    /**
     * Returns true if there are any received ops that are not yet ordered.
     */
    hasPendingWork(): Promise<boolean>;
    connectWebSocket(tenantId: string, documentId: string, token: string, client: IClient, protocolVersions: string[]): [IWebSocket, Promise<IConnected>];
}
//# sourceMappingURL=localDeltaConnectionServer.d.ts.map