"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalWebSocketServer = exports.LocalWebSocket = void 0;
const events_1 = require("events");
const server_memory_orderer_1 = require("@fluidframework/server-memory-orderer");
const uuid_1 = require("uuid");
class LocalWebSocket {
    constructor(id, server) {
        this.id = id;
        this.server = server;
        this.events = new events_1.EventEmitter();
        this.rooms = new Set();
        this._connected = true;
        this.subscriber = new server_memory_orderer_1.WebSocketSubscriber(this);
    }
    get connected() {
        return this._connected;
    }
    on(event, listener) {
        this.events.on(event, listener);
    }
    async join(roomId) {
        this.server.pubsub.subscribe(roomId, this.subscriber);
        this.rooms.add(roomId);
        return;
    }
    send(event, ...args) {
        this.events.emit(event, ...args);
    }
    emit(event, ...args) {
        this.events.emit(event, ...args);
    }
    emitToRoom(roomId, event, ...args) {
        this.server.pubsub.publish(roomId, event, ...args);
    }
    removeListener(event, listener) {
        this.events.removeListener(event, listener);
    }
    // Add `off` method the socket which is called by the base class `DocumentDeltaConnection` to remove
    // event listeners.
    // We may have to add more methods from SocketIOClient.Socket if they start getting used.
    off(event, listener) {
        this.removeListener(event, listener);
        return this;
    }
    disconnect(close) {
        for (const roomId of this.rooms) {
            this.server.pubsub.unsubscribe(roomId, this.subscriber);
        }
        this._connected = false;
        this.emit("disconnect");
    }
}
exports.LocalWebSocket = LocalWebSocket;
class LocalWebSocketServer {
    constructor(pubsub) {
        this.pubsub = pubsub;
        this.events = new events_1.EventEmitter();
    }
    on(event, listener) {
        this.events.on(event, listener);
    }
    async close() {
        this.events.removeAllListeners();
        return Promise.resolve();
    }
    createConnection() {
        const socket = new LocalWebSocket((0, uuid_1.v4)(), this);
        const mockRequest = { url: "TestWebSocket" };
        this.events.emit("connection", socket, mockRequest);
        return socket;
    }
}
exports.LocalWebSocketServer = LocalWebSocketServer;
//# sourceMappingURL=localWebSocketServer.js.map